@@ -1,4 +1,4 @@
-# Globals to make R CMD check not spit out "no visible binding for global 
+# Globals to make R CMD check not spit out "no visible binding for global
 #   variable" notes.
 # Basically, R CMD check doesn't like it when you don't quote the "V1" in
 #   a call like DT[, V1].
@@ -6,20 +6,20 @@
 # Also: see hadley's comments on his own post there. They're great.
 
 utils::globalVariables(c(
-    '.'
-    , '.I'
-    , '.id'
-    , 'alias'
-    , 'field'
-    , 'index'
-    , 'V1'
-    , 'V2'
+    "."
+    , ".I"
+    , ".id"
+    , "alias"
+    , "field"
+    , "index"
+    , "V1"
+    , "V2"
 ))
 
 
 # NULL object for common parameter documentation
-#' @param es_host A string identifying an Elasticsearch host. This should be of the form 
-#'        \code{[transfer_protocol][hostname]:[port]}. For example, \code{'http://myindex.thing.com:9200'}. 
+#' @param es_host A string identifying an Elasticsearch host. This should be of the form
+#'        \code{[transfer_protocol][hostname]:[port]}. For example, \code{'http://myindex.thing.com:9200'}.
 #' @param es_index The name of an Elasticsearch index to be queried. Note that passing
 #'                 \code{NULL} is not supported. Technically, not passing an index
 #'                 to Elasticsearch is legal and results in searching over all indexes.
@@ -29,5 +29,6 @@ utils::globalVariables(c(
 #' @name doc_shared
 #' @title NULL Object For Common Documentation
 #' @description This is a NULL object with documentation so that later functions can call
-#' inheritParams
+#'              inheritParams
+#' @keywords internal
 NULL
