@@ -1,24 +1,21 @@
 # Configure logger (suppress all logs in testing)
 loggerOptions <- futile.logger::logger.options()
-if (!identical(loggerOptions, list())){
-    origLogThreshold <- loggerOptions[[1]][['threshold']]    
+if (!identical(loggerOptions, list())) {
+    origLogThreshold <- loggerOptions[[1]][["threshold"]]
 } else {
     origLogThreshold <- futile.logger::INFO
 }
 futile.logger::flog.threshold(0)
 
-context("parse_date_time")
-
-
 # Correctly adjusts UTC date-times
-test_that("parse_date_time should transform the indicated date_cols to POSIXct with timezone UTC if they're given in UTC",{
+test_that("parse_date_time should transform the indicated date_cols to POSIXct with timezone UTC if they're given in UTC", {
     testDT <- data.table::data.table(
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
-    newDT <- parse_date_time(testDT, date_cols = c("dateTime"))
-    
-    expect_true("POSIXct" %in% class(newDT$dateTime))
+    newDT <- parse_date_time(testDT, date_cols = "dateTime")
+
+    expect_true(inherits(newDT$dateTime, "POSIXct"))
     expect_identical(
         newDT
         , data.table::data.table(
@@ -29,14 +26,14 @@ test_that("parse_date_time should transform the indicated date_cols to POSIXct w
 })
 
 # Correctly adjusts non-UTC date-times
-test_that("parse_date_time should transform the indicated date_cols to POSIXct with timezone UTC correctly even if the dates are not specified in UTC", {
+test_that("parse_date_time should transform the indicated date_cols to POSIXct with timezone UTC correctly even if the dates are not specified in UTC", {  # nolint[line_length]
     testDT <- data.table::data.table(
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00A", "2015-03-04T15:25:00B")
     )
-    newDT <- parse_date_time(testDT, date_cols = c("dateTime"))
-    
-    expect_true("POSIXct" %in% class(newDT$dateTime))
+    newDT <- parse_date_time(testDT, date_cols = "dateTime")
+
+    expect_true(inherits(newDT$dateTime, "POSIXct"))
     expect_identical(
         newDT
         , data.table::data.table(
@@ -47,14 +44,14 @@ test_that("parse_date_time should transform the indicated date_cols to POSIXct w
 })
 
 # Returns object of class POSIXct
-test_that("parse_date_time should transform the indicated date_cols to class POSIXct",{
+test_that("parse_date_time should transform the indicated date_cols to class POSIXct", {
     testDT <- data.table::data.table(
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
-    newDT <- parse_date_time(testDT, date_cols = c("dateTime"))
-    
-    expect_true("POSIXct" %in% class(newDT$dateTime))
+    newDT <- parse_date_time(testDT, date_cols = "dateTime")
+
+    expect_true(inherits(newDT$dateTime, "POSIXct"))
     expect_identical(
         newDT
         , data.table::data.table(
@@ -71,11 +68,11 @@ test_that("parse_date_time should perform adjustments only on the columns you as
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
         , otherDate = c("2014-03-11T12:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
-    newDT <- parse_date_time(testDT, date_cols = c("dateTime"))
-    
+    newDT <- parse_date_time(testDT, date_cols = "dateTime")
+
     expect_true(all(c("dateTime", "otherDate") %in% names(newDT)))
-    expect_true("POSIXct" %in% class(newDT$dateTime))
-    expect_true("character" %in% class(newDT$otherDate))
+    expect_true(inherits(newDT$dateTime, "POSIXct"))
+    expect_true(is.character(newDT$otherDate))
     expect_identical(
         newDT
         , data.table::data.table(
@@ -87,17 +84,17 @@ test_that("parse_date_time should perform adjustments only on the columns you as
 })
 
 # works for multiple date columns
-test_that("parse_date_time should perform adjustments for multiple data columns if asked",{
+test_that("parse_date_time should perform adjustments for multiple data columns if asked", {
     testDT <- data.table::data.table(
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
         , otherDate = c("2014-03-11T12:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
     newDT <- parse_date_time(testDT, date_cols = c("dateTime", "otherDate"))
-          
+
     expect_true(all(c("dateTime", "otherDate") %in% names(newDT)))
-    expect_true("POSIXct" %in% class(newDT$dateTime))
-    expect_true("POSIXct" %in% class(newDT$otherDate))
+    expect_true(inherits(newDT$dateTime, "POSIXct"))
+    expect_true(inherits(newDT$otherDate, "POSIXct"))
     expect_identical(
         newDT
         , data.table::data.table(
@@ -114,7 +111,7 @@ test_that("parse_date_time should give an informative error if you pass non-char
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
-    
+
     expect_error({
         parse_date_time(testDT, date_cols = list("dateTime"))
     }, regexp = "The date_cols argument in parse_date_time expects a character vector")
@@ -126,10 +123,10 @@ test_that("parse_date_time should give an informative error if you don't pass it
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
-    
+
     expect_error({
         parse_date_time(testDF, date_cols = "dateTime")
-    }, regexp = "parse_date_time expects to receive a data\\.table object")
+    }, regexp = "parse_date_time expects to receive a data\\.table object")  # nolint[non_portable_path]
 })
 
 # Gives informative error if you ask to adjust date_cols that don't exist
@@ -138,7 +135,7 @@ test_that("parse_date_time should give an informative error if you give it dateC
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
-    
+
     expect_error({
         parse_date_time(testDT, date_cols = c("dateTime", "dateTyme"))
     }, regexp = "do not actually exist in input_df")
@@ -150,11 +147,11 @@ test_that("parse_date_time should leave the original DT unchanged", {
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00Z", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
     )
-    
+
     beforeDT <- data.table::copy(testDT)
     origAddress <- data.table::address(testDT)
     newDT <- parse_date_time(testDT, date_cols = "dateTime")
-    
+
     expect_identical(testDT, beforeDT)
     expect_identical(origAddress, data.table::address(testDT))
     expect_true(origAddress != data.table::address(newDT))
@@ -162,7 +159,7 @@ test_that("parse_date_time should leave the original DT unchanged", {
 
 # Substitutes in assume_tz if missing a timezone
 test_that("parse_date_time should leave the original DT unchanged", {
-    
+
     testDT <- data.table::data.table(
         id = c("a", "b", "c")
         , dateTime = c("2016-07-16T21:15:00", "2015-04-16T02:15:00Z", "2015-03-04T15:25:00Z")
@@ -170,10 +167,9 @@ test_that("parse_date_time should leave the original DT unchanged", {
     beforeDT <- data.table::copy(testDT)
     origAddress <- data.table::address(testDT)
     newDT <- parse_date_time(testDT, date_cols = "dateTime", assume_tz = "UTC")
-    
-    expect_identical(newDT[id=="a", dateTime], as.POSIXct("2016-07-16 21:15:00", tz = "UTC"))
+
+    expect_identical(newDT[id == "a", dateTime], as.POSIXct("2016-07-16 21:15:00", tz = "UTC"))
 })
 
 ##### TEST TEAR DOWN #####
 futile.logger::flog.threshold(origLogThreshold)
-rm(list = ls())
